@@ -1,67 +1,67 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE" sourcelanguage="en">
+<TS version="2.0" language="nl_NL" sourcelanguage="en">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Copy</source>
-        <translation>Kopieren</translation>
+        <translation type="unfinished">Kopiëren</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Rename</source>
-        <translation>Umbenennen</translation>
+        <translation type="unfinished">Hernoemen</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Move</source>
-        <translation>Verschieben</translation>
+        <translation type="unfinished">Verplaatsen</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Delete</source>
-        <translation>Löschen</translation>
+        <translation type="unfinished">Verwijderen</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Edit</source>
-        <translation>Bearbeiten</translation>
+        <translation type="unfinished">Bewerken</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Share</source>
-        <translation>Freigeben</translation>
+        <translation type="unfinished">Delen</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Change icon</source>
-        <translation>Ändern Sie das Symbol</translation>
+        <translation type="unfinished">Wijzigen icoon</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
-        <translation>Komprimieren</translation>
+        <translation type="unfinished">Comprimeren</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Documents</source>
-        <translation>Dokumente</translation>
+        <translation type="unfinished">Documenten</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Images</source>
-        <translation>Fotos</translation>
+        <translation type="unfinished">Afbeeldingen</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Camera</source>
-        <translation>Bilder</translation>
+        <translation type="unfinished">Camera</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Sounds</source>
-        <translation>Töne</translation>
+        <translation type="unfinished">Geluiden</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
@@ -71,37 +71,37 @@
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Added to Clipboard</source>
-        <translation>In Zwischenablage kopieren</translation>
+        <translation type="unfinished">Aan klembord toegevoegd</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>ERROR: Nothing selected to paste</source>
-        <translation>FEHLER: Nichts zum Einfügen markiert</translation>
+        <translation type="unfinished">FOUT: niets geseleteerd om te plakken</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Cannot create symlink in this folder</source>
-        <translation>Verknüpfung kann in diesem Ordner nicht erstellt werden</translation>
+        <translation type="unfinished">Kan geen symlink in deze map maken</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
-        <translation>Nicht genug Platz zum Fortsetzen.</translation>
+        <translation type="unfinished">Niet genoeg ruimte om verder te gaan.</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>You don&apos;t have permissions to proceed.</source>
-        <translation>Sie haben keine Berechtigung zum Fortsetzen.</translation>
+        <translation type="unfinished">Geen rechten om verder te gaan.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>About</source>
-        <translation>Info</translation>
+        <translation type="unfinished">Over</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Broken Symlink!</source>
-        <translation>Defekter symbolischer Link!</translation>
+        <translation type="unfinished">Ongeldige Symlink!</translation>
     </message>
 </context>
 <context>
@@ -109,7 +109,7 @@
     <message>
         <location filename="../bookwindow.cpp" line="10"/>
         <source>Bookmarks</source>
-        <translation>Lesezeichen</translation>
+        <translation type="unfinished">Favorieten</translation>
     </message>
 </context>
 <context>
@@ -117,22 +117,22 @@
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Home folder</source>
-        <translation>Arbeitsplatz</translation>
+        <translation type="unfinished">Home map</translation>
     </message>
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Compress destination</source>
-        <translation>Zief für die Komprimierung</translation>
+        <translation type="unfinished">Doel comprimeren</translation>
     </message>
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Extract destination</source>
-        <translation>Ziel für die Dekomprimierung</translation>
+        <translation type="unfinished">Doel uitpakken</translation>
     </message>
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Symlink destination</source>
-        <translation>Ziel der Verknüpfung</translation>
+        <translation type="unfinished">Symlink doel</translation>
     </message>
 </context>
 <context>
@@ -140,7 +140,7 @@
     <message>
         <location filename="../clipboard.cpp" line="10"/>
         <source>Clipboard</source>
-        <translation>Zwischenablage</translation>
+        <translation type="unfinished">Klembord</translation>
     </message>
 </context>
 <context>
@@ -148,17 +148,17 @@
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
         <source>Bookmarks</source>
-        <translation>Lesezeichen</translation>
+        <translation type="unfinished">Favorieten</translation>
     </message>
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
         <source>Delete</source>
-        <translation>Löschen</translation>
+        <translation type="unfinished">Verwijderen</translation>
     </message>
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
         <source>Rename</source>
-        <translation>Umbenennen</translation>
+        <translation type="unfinished">Hernoemen</translation>
     </message>
 </context>
 <context>
@@ -166,52 +166,52 @@
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Tools</source>
-        <translation>Werkzeuge</translation>
+        <translation type="unfinished">Tools</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Add to Bookmarks</source>
-        <translation>Zu Lesezeichen hinzufügen</translation>
+        <translation type="unfinished">Voeg aan favorieten toe</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new folder</source>
-        <translation>Neuen Ordner Erstellen</translation>
+        <translation type="unfinished">Nieuwe map maken</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new document</source>
-        <translation>Neues Dokument erstellen</translation>
+        <translation type="unfinished">Nieuw document maken</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Open terminal here</source>
-        <translation>Terminal hier öffnen</translation>
+        <translation type="unfinished">Open terminal hier</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new symlink</source>
-        <translation>Neue Verknüpfung erstellen</translation>
+        <translation type="unfinished">Maak nieuwe symlink</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
-        <translation>Sortieren</translation>
+        <translation type="unfinished">Sorteer</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Paste from clipboard</source>
-        <translation>Einfügen aus Zwischenablage</translation>
+        <translation type="unfinished">Plak uit klembord</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Cut from clipboard</source>
-        <translation>Aus Zwischenablage ausschneiden</translation>
+        <translation type="unfinished">Knip uit klembord</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>ERROR: Nothing selected to paste</source>
-        <translation>FEHLER: Nichts zum einfügen ausgewählt</translation>
+        <translation type="unfinished">FOUT: Niets geselecteerd om te plakken</translation>
     </message>
 </context>
 <context>
@@ -219,17 +219,17 @@
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Share</source>
-        <translation>Freigeben</translation>
+        <translation type="unfinished">Delen</translation>
     </message>
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Send via bluetooth</source>
-        <translation>Über Bluetooth senden</translation>
+        <translation type="unfinished">Verzenden via bluetooth</translation>
     </message>
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Send via e-mail</source>
-        <translation>Per E-Mail senden</translation>
+        <translation type="unfinished">Verzenden via e-mail</translation>
     </message>
 </context>
 <context>
@@ -237,42 +237,42 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>%1 of %2 completed</source>
-        <translation>%1 von %2 erledigt</translation>
+        <translation type="unfinished">%1 van %2 klaar</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Warning</source>
-        <translation>Warnung</translation>
+        <translation type="unfinished">Waarschuwing</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copy Warning</source>
-        <translation>Kopierwarnung</translation>
+        <translation type="unfinished">Copie Waarschuwing</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source doesn&apos;t exist.</source>
-        <translation>Quelle existiert nicht.</translation>
+        <translation type="unfinished">Bron bestaat niet</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>No enough space for copy the file.</source>
-        <translation>Nicht genug Platz zum kopieren der Datei.</translation>
+        <translation type="unfinished">Niet genoeg ruimte om de file te kopiëren</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source file is a directory. Omitting source directory.</source>
-        <translation>Ursprungsdatei ist ein Ordner und wird ausgelassen.</translation>
+        <translation type="unfinished">Bron is een map. Sla bron map over.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source directory is a file. Omitting source file.</source>
-        <translation>Ursprungsordner ist eine Datei und wird ausgelassen.</translation>
+        <translation type="unfinished">Bron map is een bestand. Sla broon bestand over.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Path to destination does not exist.</source>
-        <translation>Pfad zum Ziel existiert nicht.</translation>
+        <translation type="unfinished">Pad naar bestemming bestaat niet.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
