@@ -220,7 +220,7 @@ void MainWindow::checkDevice()
                     ui->listWidget->addItem(item1);
                     ui->listWidget->item(ui->listWidget->count()-1)->setHidden(true);
 
-                    procesos += QString("blkid " + line);
+                    procesos += QString("/sbin/blkid " + line);
 
                 }
             }
@@ -237,7 +237,7 @@ void MainWindow::execDevice()
         proc = new QProcess(this);
         connect ( proc, SIGNAL(finished(int)), this, SLOT(checkFinished(int)) );
         proc->start(procesos.at(0));
-        //qDebug() << "Processing: " << procesos.at(0);
+        // qDebug() << "Processing: " << procesos.at(0);
 }
 
 void MainWindow::checkFinished(int)
